﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Emotive.Otx.Runtime.Api.Otx.Parameter;

namespace Emotive.Otx.Runtime.Sample
{
    public partial class CustomScreenForm : Form
    {
        private TableLayoutPanel tableLayoutPanel;

        private string screen;
        private ScreenParameter[] screenParameters;
        private bool modal;
        private Dictionary<string, Control> controlsDict = new Dictionary<string, Control>();
        private Api.Types.ScreenHandle screenHandle;

        public CustomScreenForm(string screen, bool modal, ScreenParameter[] screenParameters, Api.Types.ScreenHandle screenHandle)
        {
            // TODO: Complete member initialization
            this.screen = screen;
            this.modal = modal;
            this.screenParameters = screenParameters;
            this.screenHandle = screenHandle;

            this.InitializeComponent();
        }

        public Api.Types.ScreenHandle ScreenHandle
        {
            get { return screenHandle; }
            set { screenHandle = value; }
        }

        private void InitializeComponent()
        {
            this.Name = "CustomScreenForm";
            this.Text = "Custom Screen - " + this.screen;
            this.MinimumSize = new Size(300, 100);
            this.ClientSize = new Size(505, 367);
            this.StartPosition = FormStartPosition.CenterParent;
            this.SizeGripStyle = SizeGripStyle.Show;
            this.ShowIcon = false;
            this.MinimizeBox = false;
            this.AutoScroll = true;

            this.tableLayoutPanel = new TableLayoutPanel();
            this.tableLayoutPanel.ColumnCount = 2;
            this.tableLayoutPanel.ColumnStyles.Add(new ColumnStyle(SizeType.AutoSize));
            this.tableLayoutPanel.ColumnStyles.Add(new ColumnStyle(SizeType.Percent, 100));
            this.tableLayoutPanel.Padding = new Padding(12);
            this.tableLayoutPanel.Anchor = AnchorStyles.Top | AnchorStyles.Left | AnchorStyles.Right;
            this.tableLayoutPanel.Location = new Point(0, 0);
            this.tableLayoutPanel.AutoSize = true;
            this.tableLayoutPanel.AutoSizeMode = AutoSizeMode.GrowOnly;
            this.tableLayoutPanel.Size = new Size(this.ClientSize.Width, 10);

            this.Controls.Add(this.tableLayoutPanel);

            this.AddScreenParameters();
        }

        private void AddScreenParameters()
        {
            this.tableLayoutPanel.RowCount = 0;
            this.tableLayoutPanel.Controls.Clear();

            if (this.screenParameters != null)
            {
                foreach (ScreenParameter screenParameter in this.screenParameters)
                {
                    this.AddScreenParameter(screenParameter);
                }
            }
        }

        private void AddScreenParameter(ScreenParameter screenParameter)
        {
            if (screenParameter != null)
            {
                this.tableLayoutPanel.RowCount++;
                this.tableLayoutPanel.RowStyles.Add(new RowStyle(SizeType.AutoSize));

                Label label = new Label();
                label.Text = screenParameter.Name;
                label.Padding = new Padding(0, 6, 0, 0);
                label.AutoSize = true;
                this.tableLayoutPanel.Controls.Add(label);

                Control control = null;
                control = this.GetParameterControl(screenParameter);
                if (control == null)
                {
                    control = new Label();
                    control.Text = "Cannot manage datatype " + screenParameter.DataType.ToString();
                    control.Enabled = false;
                }

                control.Dock = DockStyle.Fill;
                this.tableLayoutPanel.Controls.Add(control);
                this.controlsDict.Add(screenParameter.Name, control);
            }
        }

        private Control GetParameterControl(ScreenParameter screenParameter)
        {
            Control control = null;

            switch (screenParameter.Direction)
            {
                case ScreenDirections.Term:
                    control = this.GetScreenTermParameterControl(screenParameter as ScreenTermParameter);
                    break;
                case ScreenDirections.In:
                    control = this.GetScreenInParameterControl(screenParameter as ScreenInParameter);
                    break;
                case ScreenDirections.InOut:
                    control = this.GetScreenInOutParameterControl(screenParameter as ScreenInOutParameter);
                    break;
                case ScreenDirections.Out:
                    control = this.GetScreenOutParameterControl(screenParameter as ScreenOutParameter);
                    break;
            }

            return control;
        }

        private Control GetScreenTermParameterControl(ScreenTermParameter screenTermParameter)
        {
            if ((screenTermParameter.DataType.Name == "String") || (screenTermParameter.DataType.Name == "Float") || (screenTermParameter.DataType.Name == "Integer"))
            {
                TextBox textBox = new TextBox();
                textBox.Text = screenTermParameter.Value != null ? screenTermParameter.Value.ToString() : null;
                textBox.Enabled = false;

                return textBox;
            }
            else if (screenTermParameter.DataType.Name == "Boolean")
            {
                CheckBox checkBox = new CheckBox();
                checkBox.Checked = Convert.ToBoolean(screenTermParameter.Value);
                checkBox.AutoSize = false;
                checkBox.Enabled = false;

                return checkBox;
            }

            return null;
        }

        private Control GetScreenInParameterControl(ScreenInParameter screenInParameter)
        {
            if ((screenInParameter.DataType.Name == "String") || (screenInParameter.DataType.Name == "Float") || (screenInParameter.DataType.Name == "Integer"))
            {
                TextBox textBox = new TextBox();
                textBox.Text = screenInParameter.Value != null ? screenInParameter.Value.ToString() : null;
                textBox.Enabled = false;

                return textBox;
            }
            else if (screenInParameter.DataType.Name == "Boolean")
            {
                CheckBox checkBox = new CheckBox();
                checkBox.Checked = Convert.ToBoolean(screenInParameter.Value);
                checkBox.AutoSize = false;
                checkBox.Enabled = false;

                return checkBox;
            }

            return null;
        }

        private Control GetScreenInOutParameterControl(ScreenInOutParameter screenInOutParameter)
        {
            if ((screenInOutParameter.DataType.Name == "String") || (screenInOutParameter.DataType.Name == "Float") || (screenInOutParameter.DataType.Name == "Integer"))
            {
                TextBox textBox = new TextBox();
                textBox.Text = screenInOutParameter.Value != null ? screenInOutParameter.Value.ToString() : null;
                textBox.Tag = screenInOutParameter;
                textBox.TextChanged += new EventHandler(control_ValueChanged);

                return textBox;
            }
            else if (screenInOutParameter.DataType.Name == "Boolean")
            {
                CheckBox checkBox = new CheckBox();
                checkBox.Checked = Convert.ToBoolean(screenInOutParameter.Value);
                checkBox.AutoSize = false;
                checkBox.Tag = screenInOutParameter;
                checkBox.CheckedChanged += new EventHandler(control_ValueChanged);

                return checkBox;
            }

            return null;
        }

        private Control GetScreenOutParameterControl(ScreenOutParameter screenOutParameter)
        {
            if ((screenOutParameter.DataType.Name == "String") || (screenOutParameter.DataType.Name == "Float") || (screenOutParameter.DataType.Name == "Integer"))
            {
                TextBox textBox = new TextBox();
                textBox.Text = screenOutParameter.InitValue != null ? screenOutParameter.InitValue.ToString() : null;
                textBox.Tag = screenOutParameter;
                textBox.TextChanged += new EventHandler(control_ValueChanged);

                return textBox;
            }
            else if (screenOutParameter.DataType.Name == "Boolean")
            {
                CheckBox checkBox = new CheckBox();
                checkBox.Checked = Convert.ToBoolean(screenOutParameter.InitValue);
                checkBox.AutoSize = false;
                checkBox.Tag = screenOutParameter;
                checkBox.CheckedChanged += new EventHandler(control_ValueChanged);

                return checkBox;
            }

            return null;
        }

        void control_ValueChanged(object sender, EventArgs e)
        {
            Control control = sender as Control;
            if (control != null && control.Tag is ScreenParameter)
            {
                ScreenParameter screenParameter = control.Tag as ScreenParameter;
                switch (screenParameter.Direction)
                {
                    case ScreenDirections.Out:

                        if (control is CheckBox)
                        {
                            (screenParameter as ScreenOutParameter).Value = (control as CheckBox).Checked;
                        }
                        else
                        {
                            (screenParameter as ScreenOutParameter).Value = control.Text;
                        }

                        break;

                    case ScreenDirections.InOut:

                        if (control is CheckBox)
                        {
                            (screenParameter as ScreenInOutParameter).Value = (control as CheckBox).Checked;
                        }
                        else
                        {
                            (screenParameter as ScreenInOutParameter).Value = control.Text;
                        }

                        break;
                }
            }
        }

        internal void UpdateParameter(ScreenParameter screenParameter)
        {
            if (this.controlsDict.ContainsKey(screenParameter.Name))
            {
                Control control = this.controlsDict[screenParameter.Name];
                if (control != null)
                {
                    if ((screenParameter.DataType.Name == "String") || (screenParameter.DataType.Name == "Float") || (screenParameter.DataType.Name == "Integer"))
                    {
                        switch (screenParameter.Direction)
                        {
                            case ScreenDirections.In:
                                control.Text = (screenParameter as ScreenInParameter).Value != null ? (screenParameter as ScreenInParameter).Value.ToString() : null;
                                break;
                            case ScreenDirections.InOut:
                                control.Text = (screenParameter as ScreenInOutParameter).Value != null ? (screenParameter as ScreenInOutParameter).Value.ToString() : null;
                                break;
                        }
                    }
                    else if (screenParameter.DataType.Name == "Boolean")
                    {
                        CheckBox checkBox = control as CheckBox;

                        switch (screenParameter.Direction)
                        {
                            case ScreenDirections.In:
                                checkBox.Checked = Convert.ToBoolean((screenParameter as ScreenInParameter).Value);
                                break;
                            case ScreenDirections.InOut:
                                checkBox.Checked = Convert.ToBoolean((screenParameter as ScreenInOutParameter).Value);
                                break;
                        }
                    }
                }
            }
        }
    }
}
