﻿//-----------------------------------------------------------------------
// <copyright file="FormValidate.cs" company="emotive GmbH & Co. KG">
//     Copyright (c) emotive GmbH & Co. KG. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Drawing;
using System.Text.RegularExpressions;
using System.Windows.Forms;

namespace Emotive.Otx.Runtime.Api.Sample
{
    public partial class FormValidate : Form
    {
        List<Error> errors;
        ContextMenuStrip contextMenu;
        public FormValidate()
        {
            InitializeComponent();
        }

        public FormValidate(List<Error> errors)
        {
            this.errors = errors;
            InitializeComponent();
        }

        private void FormValidate_Load(object sender, EventArgs e)
        {
            for (int i = 0; i < errors.Count; i++)
            {
                Error error = errors[i];
                Image image = null;
                if (error.Severity == SeverityType.Critical)
                {
                    image = global::Emotive.Otx.Runtime.Sample.Properties.Resources.Error;
                }
                else
                {
                    image = global::Emotive.Otx.Runtime.Sample.Properties.Resources.Warning;
                }

                object[] values = new object[] { image, i + 1, this.ClearHtmlTags(error.Message), (String.IsNullOrEmpty(error.ScopeName) ? (String.IsNullOrEmpty(error.ScopeType) ? string.Empty : "(" + error.ScopeType + ")") : error.ScopeName), error.ElementType, error.ErrorCode, error.ProcedureName, error.PackageName, error.DocumentName, error.ProjectName };
                this.gridViewError.Rows.Add(values);
            }

            this.gridViewError.CellMouseClick += new DataGridViewCellMouseEventHandler(gridViewError_CellMouseClick);
            this.gridViewError.PreviewKeyDown += new PreviewKeyDownEventHandler(gridViewError_PreviewKeyDown);

            ToolStripMenuItem menuItem = new ToolStripMenuItem("&Copy");
            menuItem.Click += new EventHandler(menuItem_Click);
            this.contextMenu = new ContextMenuStrip();
            this.contextMenu.Items.Add(menuItem);
        }

        private string ClearHtmlTags(string text)
        {
            return Regex.Replace(text, @"<(.|\n)*?>", string.Empty);
        }

        void gridViewError_PreviewKeyDown(object sender, PreviewKeyDownEventArgs e)
        {
            switch (e.KeyCode | e.Modifiers)
            {
                case Keys.Control | Keys.C:
                    if (this.gridViewError.CurrentCell != null && this.gridViewError.CurrentCell.Value != null && !string.IsNullOrEmpty(this.gridViewError.CurrentCell.Value.ToString()))
                    {
                        System.Windows.Forms.Clipboard.SetText(this.gridViewError.CurrentCell.Value.ToString());
                    }
                    break;
            }
        }

        void menuItem_Click(object sender, EventArgs e)
        {
            if (this.gridViewError.CurrentCell != null && this.gridViewError.CurrentCell.Value != null && !string.IsNullOrEmpty(this.gridViewError.CurrentCell.Value.ToString()))
            {
                System.Windows.Forms.Clipboard.SetText(this.gridViewError.CurrentCell.Value.ToString());
            }
        }

        void gridViewError_CellMouseClick(object sender, DataGridViewCellMouseEventArgs e)
        {
            if (e.RowIndex > -1 && e.ColumnIndex > -1)
            {
                this.gridViewError.CurrentCell = this.gridViewError.Rows[e.RowIndex].Cells[e.ColumnIndex];
                if (e.Button == System.Windows.Forms.MouseButtons.Right)
                {
                    this.gridViewError.CurrentCell.ContextMenuStrip = this.contextMenu;
                    this.gridViewError.CurrentCell.ContextMenuStrip.Show(Cursor.Position);
                }
            }
        }
    }
}
