﻿//-----------------------------------------------------------------------
// <copyright file="DiagComSetting.cs" company="emotive GmbH & Co. KG">
//     Copyright (c) emotive GmbH & Co. KG. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Forms;

namespace Emotive.Otx.Runtime.Api.Sample.Setting
{
    public partial class DiagComSetting : ProjectOptionsPage
    {
        #region Fields
        string oldProject;
        string oldVehicle;
        bool isChange = false;
        #endregion

        #region Contructs
        public DiagComSetting(ProjectSetting.ProjectSettings projectSetting)
            : base(projectSetting)
        {
            this.InitializeComponent();
            this.Load += new EventHandler(this.OdxOptions_Load);
        }

        public DiagComSetting()
            : base(null)
        {
            this.InitializeComponent();
            this.Load += new EventHandler(this.OdxOptions_Load);
        }
        #endregion

        #region Methods
        private void OdxOptions_Load(object sender, EventArgs e)
        {
            this.Localize();
            this.oldProject = this.ProjectSetting.DiagComSettings.Project;
            this.oldVehicle = this.ProjectSetting.DiagComSettings.Vehicle;

            this.comboProject.DropDownStyle = ComboBoxStyle.DropDownList;
            List<string> list = new List<string>();
            list.Add("None");
            list.AddRange(this.ProjectSetting.DiagComSettings.Projects);
            this.comboProject.DataSource = null;
            this.comboProject.Items.Clear();
            this.comboProject.DataSource = list;
            if (!string.IsNullOrEmpty(this.oldProject))
            {
                this.comboProject.SelectedItem = this.oldProject;
            }
            else
            {
                this.comboProject.SelectedIndex = 0;
            }

            this.comboVehicleInfo.SelectedItem = this.oldVehicle;
        }

        private void Localize()
        {
            this.labelItemODXMvciServerDescription.Text = "Access via database part of a MVCI server (diagnostic runtime system). You must first select the project and then a vehicle within this project. You mus set the ODX data within the configuration of the runtime system.";
        }

        public override void SaveOptions()
        {
            if (this.ProjectSetting.DiagComSettings == null)
            {
                return;
            }

            if (this.comboProject.SelectedItem != null)
            {
                if (this.comboProject.SelectedIndex == 0)
                {
                    this.ProjectSetting.DiagComSettings.Project = string.Empty;
                }
                else
                {
                    this.ProjectSetting.DiagComSettings.Project = this.comboProject.SelectedItem.ToString();
                }
            }

            if (this.comboVehicleInfo.SelectedItem != null)
            {
                this.ProjectSetting.DiagComSettings.Vehicle = this.comboVehicleInfo.SelectedItem.ToString();
            }
        }

        private void FillVehicle()
        {
            List<string> list = new List<string>();
            list.AddRange(this.ProjectSetting.DiagComSettings.GetVehicles(this.ProjectSetting.DiagComSettings.Project).ToList());
            this.comboVehicleInfo.DataSource = null;
            this.comboVehicleInfo.Items.Clear();
            this.comboVehicleInfo.DataSource = list;
            if (list.Count > 0)
            {
                this.comboVehicleInfo.SelectedIndex = 0;
            }

        }

        private void comboProject_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (this.comboProject.SelectedItem != null)
            {
                this.isChange = true;
                if (this.comboProject.SelectedIndex == 0)
                {
                    this.ProjectSetting.DiagComSettings.Project = string.Empty;
                }
                else
                {
                    this.ProjectSetting.DiagComSettings.Project = this.comboProject.SelectedItem.ToString();
                }
            }

            FillVehicle();
        }

        public override void RollBack()
        {
            if (this.isChange)
            {
                this.ProjectSetting.DiagComSettings.Project = this.oldProject;
                this.ProjectSetting.DiagComSettings.Vehicle = this.oldVehicle;
            }
        }


        private void comboVehicleInfo_SelectedIndexChanged(object sender, EventArgs e)
        {
            this.isChange = true;
        }

        #endregion
    }
}
