﻿//-----------------------------------------------------------------------
// <copyright file="LoggingControl.cs" company="emotive GmbH & Co. KG">
//     Copyright (c) emotive GmbH & Co. KG. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Windows.Forms;

namespace Emotive.Otx.Runtime.Api.Sample.Setting
{
    /// <summary>
    /// Options for the Logging
    /// </summary>
    public partial class LoggingControl : ProjectOptionsPage
    {
        #region Fields
        /// <summary>
        /// Initializes the object depending on the ConfigControl of each LoggingOptions element
        /// </summary>
        private StandardLoggingConfigOptions loggingLibraryOptionControl;

        #endregion

        #region Ctors
        /// <summary>
        /// Initializes a new instance of the LoggingOptions class.
        /// </summary>
        /// <param name="projectConfig">A ProjectSettings Variable</param>
        public LoggingControl(ProjectSetting.ProjectSettings projectSetting)
            : base(projectSetting)
        {
            InitializeComponent();
            this.Load += new EventHandler(this.LoggingOptions_Load);
        }

        #endregion

        #region Methods
        /// <summary>
        /// Calls the SaveOptions method of the loggingLibraryOptionControl class
        /// </summary>
        public void SaveOptions()
        {
            if (this.loggingLibraryOptionControl != null)
            {
                this.loggingLibraryOptionControl.SaveOptions();
            }
        }

        /// <summary>
        /// Loads the data into the ComboBox when loadding the LoggingOptions control
        /// </summary>
        /// <param name="sender">The I18NOptions control</param>
        /// <param name="e">The parameter contains the data event</param>
        private void LoggingOptions_Load(object sender, EventArgs e)
        {
            this.loggingLibraryOptionControl = new StandardLoggingConfigOptions(ProjectSetting);
            this.AddControl2OptionsPanel(this.loggingLibraryOptionControl);
            this.loggingLibraryOptionControl.Dock = DockStyle.Fill;
        }

        /// <summary>
        /// Adds the StandardLoggingConfigOptions into the panelSubSettings
        /// </summary>
        /// <param name="control">The StandardLoggingConfigOptions</param>
        private void AddControl2OptionsPanel(Control control)
        {
            this.panelSubSettings.Controls.Clear();
            this.panelSubSettings.Controls.Add(control);
        }

        #endregion
    }
}
