﻿//-----------------------------------------------------------------------
// <copyright file="ProjectOptionsForm.cs" company="emotive GmbH & Co. KG">
//     Copyright (c) emotive GmbH & Co. KG. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Windows.Forms;

namespace Emotive.Otx.Runtime.Api.Sample.Setting
{
    public partial class ProjectOptionsForm : Form
    {
        public enum SelectedButton
        {
            DiagRuntime,
            DiagDatabase,
            OtfRuntime,
            UnitSpec,
            ScreenMappings,
            I18nOption,
            RuntimeEnviroment,
            LoggingOption,
        }

        private ProjectSetting.ProjectSettings projectSetting;
        private DiagComSetting diagComControl;
        private HmiSettingControl hmiControl;
        private I18NControl i18nControl;
        private LoggingControl loggingControl;
        private QuantitiesControl quantitiesControl;
        private RuntimeEnviromentOptions runtimeEnviromentControl;
        private SelectedButton selectedButton = SelectedButton.OtfRuntime;
        RuntimeManager rtManager;

        public ProjectOptionsForm()
        {
            InitializeComponent();

            this.Load += new EventHandler(ProjectOptionsForm_Load);
        }

        public ProjectOptionsForm(ProjectSetting.ProjectSettings projectSetting, RuntimeManager rtManager)
            : this()
        {
            this.projectSetting = projectSetting;
            this.rtManager = rtManager;
        }

        void ProjectOptionsForm_Load(object sender, EventArgs e)
        {
            this.runtimeEnviromentControl = new RuntimeEnviromentOptions(this.projectSetting, this.rtManager);
            this.diagComControl = new DiagComSetting(this.projectSetting);
            this.diagComControl.Dock = DockStyle.Fill;
            this.hmiControl = new HmiSettingControl(this.projectSetting);
            this.hmiControl.Dock = DockStyle.Fill;
            this.i18nControl = new I18NControl(this.projectSetting);
            this.i18nControl.Dock = DockStyle.Fill;
            this.loggingControl = new LoggingControl(this.projectSetting);
            this.loggingControl.Dock = DockStyle.Fill;
            this.quantitiesControl = new QuantitiesControl(this.projectSetting);
            this.quantitiesControl.Dock = DockStyle.Fill;
            this.runtimeEnviromentControl.Dock = DockStyle.Fill;

            switch (selectedButton)
            {
                case SelectedButton.OtfRuntime:
                case SelectedButton.DiagRuntime:
                case SelectedButton.DiagDatabase:
                case SelectedButton.UnitSpec:
                case SelectedButton.ScreenMappings:
                case SelectedButton.I18nOption:
                case SelectedButton.RuntimeEnviroment:
                case SelectedButton.LoggingOption:
                default:
                    buttonRuntimeEnviroment_Click(null, null);
                    break;
            }
        }

        private void ChangeBackColorButton(Button button)
        {
            foreach (Control ctrl in tableLayoutPanel1.Controls)
            {
                if (ctrl is Button)
                {
                    ctrl.ForeColor = System.Drawing.SystemColors.ControlText;
                    ctrl.BackColor = System.Drawing.SystemColors.Window;
                }
            }

            button.ForeColor = System.Drawing.SystemColors.HighlightText;
            button.BackColor = System.Drawing.SystemColors.Highlight;
        }

        private void buttonOk_Click(object sender, EventArgs e)
        {
            this.runtimeEnviromentControl.SaveOptions();
            this.loggingControl.SaveOptions();
            this.diagComControl.SaveOptions();
            this.i18nControl.SaveOptions();
            this.hmiControl.SaveOptions();
            this.quantitiesControl.SaveOptions();

            this.Close();

        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            if (this.i18nControl != null)
            {
                this.i18nControl.RollBack();
            }

            if (this.diagComControl != null)
            {
                this.diagComControl.RollBack();
            }

            this.Close();
        }

        private void buttonDiagDatabase_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.itemPanelRightGeneral.Controls.Add(this.diagComControl);
            ChangeBackColorButton(buttonDiagDatabase);
        }

        private void buttonUnitSpec_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.itemPanelRightGeneral.Controls.Add(this.quantitiesControl);
            ChangeBackColorButton(buttonUnitSpec);
        }

        private void buttonscreenMappingOptions_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.itemPanelRightGeneral.Controls.Add(this.hmiControl);
            ChangeBackColorButton(buttonScreenMappings);
        }

        private void buttonI18nOptions_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.itemPanelRightGeneral.Controls.Add(this.i18nControl);
            ChangeBackColorButton(buttonI18nOption);
        }

        private void buttonRuntimeEnviroment_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.runtimeEnviromentControl = new RuntimeEnviromentOptions(this.projectSetting, this.rtManager);
            this.runtimeEnviromentControl.Dock = DockStyle.Fill;
            this.itemPanelRightGeneral.Controls.Add(this.runtimeEnviromentControl);
            ChangeBackColorButton(buttonRuntimeEnviroment);
        }

        private void buttonLogging_Click(object sender, EventArgs e)
        {
            this.buttonDelete.Visible = false;
            this.itemPanelRightGeneral.Controls.Clear();
            this.itemPanelRightGeneral.Controls.Add(this.loggingControl);
            ChangeBackColorButton(buttonLogging);
        }
    }
}
