﻿//-----------------------------------------------------------------------
// <copyright file="StandardLoggingConfigOptions.cs" company="emotive GmbH & Co. KG">
//     Copyright (c) emotive GmbH & Co. KG. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.IO;
using System.Windows.Forms;
using Emotive.Otx.Runtime.Api.Types;

namespace Emotive.Otx.Runtime.Api.Sample.Setting
{
    public partial class StandardLoggingConfigOptions : UserControl
    {
        ProjectSetting.ProjectSettings projectSetting;

        public StandardLoggingConfigOptions(ProjectSetting.ProjectSettings projectSetting)
        {
            InitializeComponent();
            this.Localize();
            this.projectSetting = projectSetting;
            this.Load += new EventHandler(StandardLoggingConfigOptions_Load);
        }

        /// <summary>
        /// Loads the data into the ComboBox when loadding the LoggingOptions control
        /// </summary>
        /// <param name="sender">The I18NOptions control</param>
        /// <param name="e">The parameter contains the data event</param>
        private void StandardLoggingConfigOptions_Load(object sender, EventArgs e)
        {
            this.txtDirectory.Text = this.projectSetting.LoggingSettings.DirectoryName;
            this.txtFileName.Text = this.projectSetting.LoggingSettings.FileName;
            this.txtFileSize.Text = this.projectSetting.LoggingSettings.MaxFileSize.ToString();
            this.txtMaxFile.Text = this.projectSetting.LoggingSettings.MaxFileNumber.ToString();
            this.txtHeaderFormat.Text = this.projectSetting.LoggingSettings.HeaderFormat;
            this.txtMessageFormat.Text = this.projectSetting.LoggingSettings.MessageFormat;

            ToolTip toolTip = new ToolTip();
            toolTip.SetToolTip(this.checkBoxLogCommunicationTrace, "The diagnostic communication is automatically saved in the log file.");
            toolTip.SetToolTip(this.checkBoxLogVariableTrace, "Each Variable Trace entry is automatically saved in the log file.");
            toolTip.SetToolTip(this.checkBoxLogOtxException, "All exceptions (handled or unhandled) occured during OTX execution are automatically saved in the log file.");
            toolTip.SetToolTip(this.checkBoxLogOtxId, "Contains the OTX IDs of the activities performed.");
            toolTip.SetToolTip(this.labelDefaulLevel, "Logging level of the OTX runtime. Messages with adjusted severity or above will be logged.");

            bool flag = this.projectSetting.LoggingSettings.IsLoggingActive;
            if (flag)
            {
                this.checkBoxOnOff.Checked = true;
            }
            else
            {
                this.checkBoxOnOff.Checked = false;
            }

            this.EnableControls(this.checkBoxOnOff.Checked);

            this.textPlaceHolders.Text = "Within Header and Message format placeholders can be used.";
            this.textPlaceHolders.Text += "\r\nThese will be replaced at runtime with the current values​​.";
            this.textPlaceHolders.Text += "\r\nThe placeholders can be formatted according to the";
            this.textPlaceHolders.Text += "\r\n\"String.Format\" Function of DotNet.";
            this.textPlaceHolders.Text += "\r\n";
            this.textPlaceHolders.Text += "\r\nList of placeholders:";
            this.textPlaceHolders.Text += "\r\n------------------------------------------------";
            this.textPlaceHolders.Text += "\r\n[Msg]	- Message";
            this.textPlaceHolders.Text += "\r\n[Lev]	- Log level (e.g. \"FATAL\")";
            this.textPlaceHolders.Text += "\r\n[Sol]	- Name of Solution";
            this.textPlaceHolders.Text += "\r\n[Proj]	- Name of current Project";
            this.textPlaceHolders.Text += "\r\n[Doc]	- Name of current Document";
            this.textPlaceHolders.Text += "\r\n[Proc]	- Name of current Procedure";
            this.textPlaceHolders.Text += "\r\n[Pack]	- Full name of the current Package";
            this.textPlaceHolders.Text += "\r\n[Now]	- Current date/time";
            this.textPlaceHolders.Text += "\r\n[usr]	- Registered User";
            this.textPlaceHolders.Text += "\r\n[Comp]	- Name of the computer";
            this.textPlaceHolders.Text += "\r\n[OTX]	- OTX Version";
            this.textPlaceHolders.Text += "\r\n[OTF]	- OTF Version";

            this.checkBoxLogCommunicationTrace.Checked = this.projectSetting.LoggingSettings.IsLogCommunicationTrace;
            this.checkBoxLogVariableTrace.Checked = this.projectSetting.LoggingSettings.IsLogVariableTrace;
            this.checkBoxLogOtxException.Checked = this.projectSetting.LoggingSettings.IsLogExceptions;
            this.checkBoxLogOtxId.Checked = this.projectSetting.LoggingSettings.IsLogOtxIds;

            this.comboBoxCommunicationTraceSeverityLevel.DataSource = Enum.GetNames(typeof(SeverityLevels));
            this.comboBoxVariableTraceSeverityLevel.DataSource = Enum.GetNames(typeof(SeverityLevels));
            this.comboBoxOtxExceptionSeverityLevel.DataSource = Enum.GetNames(typeof(SeverityLevels));
            this.comboBoxOtxIdSeverityLevel.DataSource = Enum.GetNames(typeof(SeverityLevels));
            this.comboBoxDefaultLevel.DataSource = Enum.GetNames(typeof(LogLevels));

            this.comboBoxOtxIdSeverityLevel.SelectedItem = this.projectSetting.LoggingSettings.LogOtxIdsSeverityLevel.ToString();
            this.comboBoxCommunicationTraceSeverityLevel.SelectedItem = this.projectSetting.LoggingSettings.LogCommunicationTraceSeverityLevel.ToString();
            this.comboBoxVariableTraceSeverityLevel.SelectedItem = this.projectSetting.LoggingSettings.LogVariableTraceSeverityLevel.ToString();
            this.comboBoxOtxExceptionSeverityLevel.SelectedItem = this.projectSetting.LoggingSettings.LogExceptionsSeverityLevel.ToString();
            this.comboBoxDefaultLevel.SelectedItem = this.projectSetting.LoggingSettings.DefaultLogLevel.ToString();

            this.comboBoxCommunicationTraceSeverityLevel.Enabled = this.checkBoxLogCommunicationTrace.Checked;
            this.comboBoxVariableTraceSeverityLevel.Enabled = this.checkBoxLogVariableTrace.Checked;
            this.comboBoxOtxExceptionSeverityLevel.Enabled = this.checkBoxLogOtxException.Checked;
            this.comboBoxOtxIdSeverityLevel.Enabled = this.checkBoxLogOtxId.Checked;
        }

        private void EnableControls(bool enable)
        {
            this.panel1.Enabled = enable;
        }

        /// <summary>
        /// Localization text for controls
        /// </summary>
        private void Localize()
        {
            this.lblDescription.Text = "The OTX logging extension writes messages to a text file. Here you can configure the extension. To write a message, the WriteLog activity of OTX is used. Please note that the setting of the optional Target property of WriteLog, the directory and file name described here are overwritten.";
        }

        /// <summary>
        /// The SaveOptions method of the loggingLibraryOptionControl class
        /// </summary>
        public void SaveOptions()
        {
            this.projectSetting.LoggingSettings.DirectoryName = this.txtDirectory.Text;
            this.projectSetting.LoggingSettings.FileName = this.txtFileName.Text;
            this.projectSetting.LoggingSettings.MaxFileSize = int.Parse(this.txtFileSize.Text);
            this.projectSetting.LoggingSettings.MaxFileNumber = int.Parse(this.txtMaxFile.Text);
            this.projectSetting.LoggingSettings.HeaderFormat = this.txtHeaderFormat.Text;
            this.projectSetting.LoggingSettings.MessageFormat = this.txtMessageFormat.Text;

            if (this.checkBoxOnOff.Checked)
            {
                this.projectSetting.LoggingSettings.IsLoggingActive = true;
            }
            else
            {
                this.projectSetting.LoggingSettings.IsLoggingActive = false;
            }

            this.projectSetting.LoggingSettings.IsLogCommunicationTrace = this.checkBoxLogCommunicationTrace.Checked;
            this.projectSetting.LoggingSettings.IsLogVariableTrace = this.checkBoxLogVariableTrace.Checked;
            this.projectSetting.LoggingSettings.IsLogExceptions = this.checkBoxLogOtxException.Checked;
            this.projectSetting.LoggingSettings.IsLogOtxIds = this.checkBoxLogOtxId.Checked;

            this.projectSetting.LoggingSettings.LogCommunicationTraceSeverityLevel = (SeverityLevels)Enum.Parse(typeof(SeverityLevels), this.comboBoxCommunicationTraceSeverityLevel.SelectedItem.ToString());
            this.projectSetting.LoggingSettings.LogVariableTraceSeverityLevel = (SeverityLevels)Enum.Parse(typeof(SeverityLevels), this.comboBoxVariableTraceSeverityLevel.SelectedItem.ToString());
            this.projectSetting.LoggingSettings.LogExceptionsSeverityLevel = (SeverityLevels)Enum.Parse(typeof(SeverityLevels), this.comboBoxOtxExceptionSeverityLevel.SelectedItem.ToString());
            this.projectSetting.LoggingSettings.LogOtxIdsSeverityLevel = (SeverityLevels)Enum.Parse(typeof(SeverityLevels), this.comboBoxOtxIdSeverityLevel.SelectedItem.ToString());
            this.projectSetting.LoggingSettings.DefaultLogLevel = (LogLevels)Enum.Parse(typeof(LogLevels), this.comboBoxDefaultLevel.SelectedItem.ToString());
        }

        private void checkBoxLogCommunicationTrace_CheckedChanged(object sender, EventArgs e)
        {
            this.comboBoxCommunicationTraceSeverityLevel.Enabled = this.checkBoxLogCommunicationTrace.Checked;
        }

        private void checkBoxLogVariableTrace_CheckedChanged(object sender, EventArgs e)
        {
            this.comboBoxVariableTraceSeverityLevel.Enabled = this.checkBoxLogVariableTrace.Checked;
        }

        private void checkBoxLogOtxException_CheckedChanged(object sender, EventArgs e)
        {
            this.comboBoxOtxExceptionSeverityLevel.Enabled = this.checkBoxLogOtxException.Checked;
        }

        private void checkBoxLogOtxId_CheckedChanged(object sender, EventArgs e)
        {
            this.comboBoxOtxIdSeverityLevel.Enabled = this.checkBoxLogOtxId.Checked;
        }

        private void btnBrowser_Click(object sender, EventArgs e)
        {
            this.folderBrowserDialog1.ShowNewFolderButton = true;
            string directory = this.projectSetting.LoggingSettings.DirectoryName;
            if (directory != null)
            {
                this.folderBrowserDialog1.SelectedPath = directory;
            }

            if (this.folderBrowserDialog1.ShowDialog() == DialogResult.OK)
            {
                this.txtDirectory.Text = this.folderBrowserDialog1.SelectedPath;
            }
        }

        private void txtFileSize_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar != '\b' && !char.IsControl(e.KeyChar))
            {
                e.Handled = !char.IsNumber(e.KeyChar);
            }
        }

        private void txtMaxFile_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar != '\b' && !char.IsControl(e.KeyChar))
            {
                e.Handled = !char.IsNumber(e.KeyChar);
            }
        }

        private void checkBoxOnOff_CheckedChanged(object sender, System.EventArgs e)
        {
            this.EnableControls(this.checkBoxOnOff.Checked);
            if (this.checkBoxOnOff.Checked)
            {
                this.checkBoxOnOff.Text = "Logging ON";
            }
            else
            {
                this.checkBoxOnOff.Text = "Logging OFF";
            }
        }

        private void btnOpen_Click(object sender, EventArgs e)
        {
            string dir = this.txtDirectory.Text;

            if (Directory.Exists(dir))
            {
                System.Diagnostics.Process.Start(dir);
            }
            else
            {
                System.Media.SystemSounds.Exclamation.Play();
            }
        }
    }
}
