﻿using System;
using System.Windows.Forms;
using Emotive.Otx.Runtime.Api;
using Emotive.Otx.Runtime.Api.Otx;
using Emotive.Otx.Runtime.Api.Otx.Parameter;

namespace OtxRuntimeApiSample
{
    public partial class Form1 : Form
    {
        RuntimeManager runtimeManager = null;

        public Form1()
        {
            InitializeComponent();
        }

        private void buttonLoad_Click(object sender, EventArgs e)
        {
            this.UseWaitCursor = true;

            this.runtimeManager = new RuntimeManager();
            this.runtimeManager.Load("./ptx/OtxRuntimeApiHelloWorld.ptx");

            this.runtimeManager.ParameterValueChanged += new RuntimeManager.ParameterValueChangedHandler(runtimeManager_ParameterValueChanged);
            this.runtimeManager.ProcedureFinished += new RuntimeManager.ProcedureFinishedHandler(runtimeManager_ProcedureFinished);
            this.runtimeManager.VariableTraceItemAdded += new RuntimeManager.VariableTraceItemAddedHandler(runtimeManager_VariableTraceItemAdded);
            this.runtimeManager.ExecutionStopped += new RuntimeManager.ExecutionStoppedHandler(runtimeManager_ExecutionStopped);
            this.runtimeManager.RuntimeExceptionOccured += new RuntimeManager.RuntimeExceptionOccuredHandler(runtimeManager_RuntimeExceptionOccured);

            this.UseWaitCursor = false;
        }

        private void runtimeManager_ParameterValueChanged(Parameter parameter)
        {
            if (parameter != null)
            {
                object value = GetParameter(parameter);
                AddEventToTextBox("ParameterValueChanged: Paramter: " + parameter.Name + ", Value: " + value != null ? value.ToString() : string.Empty);
            }
        }

        private void runtimeManager_ProcedureFinished(Procedure procedure)
        {
            if (procedure != null)
            {
                AddEventToTextBox("ProcedureFinished: Procedure: " + procedure.Name);
            }
        }

        private void runtimeManager_VariableTraceItemAdded(VariableTraceItem traceItem)
        {
            if (traceItem != null)
            {
                AddEventToTextBox("VariableTraceItemAdded: Variable: " + traceItem.Variable + ", Value: " + traceItem.Value);
            }
        }

        private void runtimeManager_ExecutionStopped()
        {
            AddEventToTextBox("ExecutionStopped");
        }

        void runtimeManager_RuntimeExceptionOccured(Procedure procedure, Exception exception)
        {
            if (procedure != null)
            {
                AddEventToTextBox("RuntimeExceptionOccured: Procedure: " + procedure.Name + ", Exception: " + exception.Message);
            }
        }

        public delegate void AddEventToTextBoxDelegate(string text);
        public AddEventToTextBoxDelegate addEventToTextBoxDelegate;

        private void AddEventToTextBox(string text)
        {
            if (this.textBox1.InvokeRequired)
            {
                addEventToTextBoxDelegate = new AddEventToTextBoxDelegate(AddEventToTextBox);
                this.Invoke(addEventToTextBoxDelegate, new object[] { text });
            }
            else
            {
                this.textBox1.Text += text + "\r\n";
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            Procedure procedure = this.runtimeManager.GetMainProcedure();

            if (procedure != null)
            {
                SetParameter(procedure.Parameters[0], "Hello World");
                procedure.Execute();
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            Procedure procedure = this.runtimeManager.Packages[0].Documents[0].Procedures[1];

            if (procedure != null)
            {
                Int64 n = 0;
                SetParameter(procedure.Parameters[0], n);
                procedure.Execute(true);
            }
        }

        private object GetParameter(Parameter parameter)
        {
            object value = null;

            if (parameter is InOutParameter)
            {
                value = (parameter as InOutParameter).Value;
            }
            else if (parameter is InParameter)
            {
                value = (parameter as InParameter).Value;
            }
            else if (parameter is OutParameter)
            {
                value = (parameter as OutParameter).Value;
            }
            
            return value;
        }

        private void SetParameter(Parameter parameter, object value)
        {
            if (parameter is InOutParameter)
            {
                (parameter as InOutParameter).Value = value;
            }
            else if (parameter is InParameter)
            {
                (parameter as InParameter).Value = value;
            }
        }
    }
}
