﻿using System;
using System.IO;
using System.Windows.Forms;
using Emotive.Otx.Runtime.Api;
using Emotive.Otx.Runtime.Api.Otx;

namespace RunPtx
{
    internal class Program
    {
        /// <summary>
        /// Execute an arbitrary PTX with this little sample console application
        /// Syntax: RunPtx.exe PtxFilename
        /// Example: RunPtx.exe "..\..\Resources\HelloWorldSimple.ptx"
        /// </summary>
        private static void Main(string[] args)
        {
            try
            {
                if (args.Length != 1)
                {
                    PrintError("Syntax: RunPtx.exe <PtxFileName>");
                }

                LoadAndRun(args[0]);
            }
            catch (Exception exception)
            {
                PrintError(exception.Message);
            }
        }

        private static void LoadAndRun(string filename)
        {
            WriteLine("****************************************************************");
            WriteLine("* EMOTIVE RunPtx sample for simple execution of PTX documents. *");
            WriteLine("****************************************************************");

            if (string.IsNullOrEmpty(filename))
            {
                throw (new Exception("Syntax: RunPtx.exe <PtxFileName>"));
            }

            filename = Path.GetFullPath(filename);
            if (!File.Exists(filename))
            {
                throw (new Exception("Wrong filename: " + filename));
            }

            Write("Create OTX-Runtime instance...");
            var runtimeManager = new RuntimeManager();
            WriteLine(" created.");
            Write(string.Format("Load PTX \"{0}\"...", filename));

            runtimeManager.RuntimeExceptionOccured += runtimeManager_RuntimeExceptionOccured;

            runtimeManager.Load(filename);
            WriteLine(" successfully loaded.");
            Write("Starting procedure...");

            var procedure = runtimeManager.GetMainProcedure();
            if (procedure != null)
            {
                procedure.Execute();
                WriteLine(" execution finished successfully.");
            }
            else
            {
                PrintError("No main procedure found!");
            }

            WriteLine("****************************************************************");
            WriteLine("* Finished                                                     *");
            WriteLine("****************************************************************");
        }

        private static void runtimeManager_RuntimeExceptionOccured(Procedure procedure, Exception exception)
        {
            PrintError(exception.Message);
        }

        private static void PrintError(string error)
        {
            WriteLine(error);
            WriteLine("****************************************************************");
            WriteLine("* Exception                                                    *");
            WriteLine("****************************************************************");

            MessageBox.Show(error, "RunPtx Exception");
        }

        private static void WriteLine(string output)
        {
            Console.WriteLine(output);
        }

        private static void Write(string output)
        {
            Console.Write(output);
        }
    }
}